lt-package: lt: Lightweight Tables via JSON Specs and JavaScript

lt-packageR Documentation

lt: Lightweight Tables via JSON Specs and JavaScript

Description

A small grammar of tables. A table is a data frame plus a list of operations (title, spanner, footnote, ...); the operations are serialized to a JSON spec and applied to a plain semantic HTML table by a tiny vanilla JavaScript runtime at render time.

Author(s)

Maintainer: Yihui Xie xie@yihui.name (ORCID) (URL: https://yihui.org) [copyright holder]

Authors:

See Also

Useful links:


lt documentation built on July 10, 2026, 1:09 a.m.