lt_move: Move Columns

View source: R/tab.R

lt_moveR Documentation

Move Columns

Description

Rearrange column display order without modifying the data frame.

Usage

lt_move(x, columns, after = NULL)

Arguments

x

An lt() object.

columns

Character vector of column names (or a one-sided formula).

after

Column name after which to place the moved columns. Use NULL to move to the start.

Value

x with the column move recorded.

Examples

lt(head(mtcars)) |> lt_move(~ gear + carb, after = "mpg")

lt documentation built on July 10, 2026, 1:09 a.m.