| format.lt_tbl | R Documentation |
lt_tbl to HTMLEmits the CSS+JS runtime and a script block carrying the table's JSON spec. Multiple tables on the same page only need the runtime once.
## S3 method for class 'lt_tbl'
format(x, fragment = TRUE, inline_assets = TRUE, assets = TRUE, ...)
x |
An |
fragment |
If |
inline_assets |
If |
assets |
Which runtime assets to include: |
... |
Reserved for future use. |
A character scalar containing HTML.
tbl = lt(head(mtcars))
html = format(tbl)
format(tbl, fragment = FALSE, inline_assets = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.