| lt-package | R Documentation |
A small grammar of tables. A table is a data frame plus a list of operations (title, spanner, footnote, ...); the operations are serialized to a JSON spec and applied to a plain semantic HTML table by a tiny vanilla JavaScript runtime at render time.
Maintainer: Yihui Xie xie@yihui.name (ORCID) (URL: https://yihui.org) [copyright holder]
Authors:
Yihui Xie xie@yihui.name (ORCID) (URL: https://yihui.org) [copyright holder]
Useful links:
Report bugs at https://github.com/yihui/lt/issues
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.