| lt_move | R Documentation |
Rearrange column display order without modifying the data frame.
lt_move(x, columns, after = NULL)
x |
An |
columns |
Character vector of column names (or a one-sided formula). |
after |
Column name after which to place the moved columns. Use
|
x with the column move recorded.
lt(head(mtcars)) |> lt_move(~ gear + carb, after = "mpg")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.